==> cognito-1.60.0-sources.jar: software/amazon/awscdk/services/cognito/DateTimeAttribute.java <==
package software.amazon.awscdk.services.cognito;

/**
 * The DateTime custom attribute type.
 * <p>
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:23.706Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cognito.$Module.class, fqn = "@aws-cdk/aws-cognito.DateTimeAttribute")
public class DateTimeAttribute extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.cognito.ICustomAttribute {

    protected DateTimeAttribute(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected DateTimeAttribute(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * EXPERIMENTAL
     * <p>
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public DateTimeAttribute(final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.cognito.CustomAttributeProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { props });
    }

    /**
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public DateTimeAttribute() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * Bind this custom attribute type to the values as expected by CloudFormation.
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cognito.CustomAttributeConfig bind() {
        return this.jsiiCall("bind", software.amazon.awscdk.services.cognito.CustomAttributeConfig.class);
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.cognito.DateTimeAttribute}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.cognito.DateTimeAttribute> {
        /**
         * EXPERIMENTAL
         * <p>
         * @return a new instance of {@link Builder}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create() {
            return new Builder();
        }

        private software.amazon.awscdk.services.cognito.CustomAttributeProps.Builder props;

        private Builder() {
        }

        /**
         * Specifies whether the value of the attribute can be changed.
         * <p>
         * For any user pool attribute that's mapped to an identity provider attribute, you must set this parameter to true.
         * Amazon Cognito updates mapped attributes when users sign in to your application through an identity provider.
         * If an attribute is immutable, Amazon Cognito throws an error when it attempts to update the attribute.
         * <p>
         * Default: false
         * <p>
         * EXPERIMENTAL
         * <p>
         * @return {@code this}
         * @param mutable Specifies whether the value of the attribute can be changed. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder mutable(final java.lang.Boolean mutable) {
            this.props().mutable(mutable);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.cognito.DateTimeAttribute}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public software.amazon.awscdk.services.cognito.DateTimeAttribute build() {
            return new software.amazon.awscdk.services.cognito.DateTimeAttribute(
                this.props != null ? this.props.build() : null
            );
        }

        private software.amazon.awscdk.services.cognito.CustomAttributeProps.Builder props() {
            if (this.props == null) {
                this.props = new software.amazon.awscdk.services.cognito.CustomAttributeProps.Builder();
            }
            return this.props;
        }
    }
}

==> cognito-1.93.0-sources.jar: software/amazon/awscdk/services/cognito/DateTimeAttribute.java <==
package software.amazon.awscdk.services.cognito;

/**
 * The DateTime custom attribute type.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:52.470Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cognito.$Module.class, fqn = "@aws-cdk/aws-cognito.DateTimeAttribute")
public class DateTimeAttribute extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.cognito.ICustomAttribute {

    protected DateTimeAttribute(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected DateTimeAttribute(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public DateTimeAttribute(final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.cognito.CustomAttributeProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { props });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public DateTimeAttribute() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * Bind this custom attribute type to the values as expected by CloudFormation.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cognito.CustomAttributeConfig bind() {
        return software.amazon.jsii.Kernel.call(this, "bind", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cognito.CustomAttributeConfig.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.cognito.DateTimeAttribute}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.cognito.DateTimeAttribute> {
        /**
         * @return a new instance of {@link Builder}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create() {
            return new Builder();
        }

        private software.amazon.awscdk.services.cognito.CustomAttributeProps.Builder props;

        private Builder() {
        }

        /**
         * Specifies whether the value of the attribute can be changed.
         * <p>
         * For any user pool attribute that's mapped to an identity provider attribute, you must set this parameter to true.
         * Amazon Cognito updates mapped attributes when users sign in to your application through an identity provider.
         * If an attribute is immutable, Amazon Cognito throws an error when it attempts to update the attribute.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param mutable Specifies whether the value of the attribute can be changed. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder mutable(final java.lang.Boolean mutable) {
            this.props().mutable(mutable);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.cognito.DateTimeAttribute}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.cognito.DateTimeAttribute build() {
            return new software.amazon.awscdk.services.cognito.DateTimeAttribute(
                this.props != null ? this.props.build() : null
            );
        }

        private software.amazon.awscdk.services.cognito.CustomAttributeProps.Builder props() {
            if (this.props == null) {
                this.props = new software.amazon.awscdk.services.cognito.CustomAttributeProps.Builder();
            }
            return this.props;
        }
    }
}
